<?php
/**
* @version $Id: jfwhois.php Fri Dec 23 09:59:50 WST 2005 shaynebartlett
* @package J! Whois
* @copyright Copyright (C) 2005 theJ!factory. All rights reserved.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
* J! Whois is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/

// NO DIRECT ACCESS
defined( '_VALID_MOS' ) or die( 'Restricted access' );-

include ($mosConfig_absolute_path.'/components/com_jfwhois/includes/jfwhois.config.php');

// Languages
if (file_exists(JF_LANGUAGE . $mosConfig_lang.'.php')) {
  require_once(JF_LANGUAGE . $mosConfig_lang.'.php');
} else {
  require_once(JF_LANGUAGE . 'english.php');	
}

// +------------------------------
//	initialize script and navigate
// +------------------------------
$EP_Dev_Whois = new EP_Dev_Whois();
$EP_Dev_Whois->navigate($_REQUEST['task']);


/* ------------------------------------------------------------------ */
//	EP-Dev Whois Main Class
//	Main class of the script. Initializes and controls all aspects of
//	the whois script, including initiailizing core, etc.
//	Date: 3/29/2005
/* ------------------------------------------------------------------ */

class EP_Dev_Whois
{
	var $CORE;
	
	/* ------------------------------------------------------------------ */
	//	Constructor
	/* ------------------------------------------------------------------ */
	

	function EP_Dev_Whois()
	{
		// set error reporting level
		error_reporting(E_ALL ^ E_NOTICE);

		// absolute path
		$this->absolute_path = $mosConfig_absolute_path;

		// detect and (if necessary) set absolute path
		if ($this->absolute_path == "")
			$this->absolute_path = JF_COMPONENT;
			
			echo
			
		// try include and error if bad abs path
		$include_success = @include_once($this->absolute_path . "classes/global.php");
		if ($include_success === false)
		{
			die("<div style=\"font-weight: bold; color: red;\">Error Loading J!Whois Script: The specified absolute path (" . JF_COMPONENT . " is incorrect.</div>");
		}

		// initialize core
		$this->CORE = new EP_Dev_Whois_Global($this->absolute_path);
	}


	/* ------------------------------------------------------------------ */
	//	navigate to $task
	//	Calls on methods corresponding to $task
	/* ------------------------------------------------------------------ */
	
	function navigate($task)
	{
		switch ($task)
		{
			case "WhoisReport" :
				$domain = $_REQUEST['domain'];
				$ext = $_REQUEST['ext'];

				// ensure extension exists
				if (empty($ext))
					$this->CORE->ERROR->stop("no_extension");

				// validate domain
				$this->CORE->DOMAINS->validateDomain($domain, $ext);

				// show report
				$this->task_WhoisReport($domain, $ext);
			break;

			case "WhoisSearch" :
				$base_extensions = array();

				// search for all extensions
				foreach(array_keys($_REQUEST) as $current_key)
				{
					if (ereg("^ext[0-9]+$", $current_key))
						$base_extensions[] = $_REQUEST[$current_key];
				}

				$domains = explode("\n", str_replace("\r\n", "\n", $_REQUEST['domain']));

				if ($this->CORE->CONFIG->BUYMODE['CONFIG']['enable'])
				{
					foreach($domains as $domain)
					{
						$extensions = $base_extensions;

						// validate domain
						$this->CORE->DOMAINS->validateDomain($domain, $extensions);

						// send to search method
						if (!empty($whoisQueries))
							$whoisQueries = array_merge($this->go_WhoisSearch($domain, $extensions, ($_REQUEST['skip_additional'] == "1")), $whoisQueries);
						else
							$whoisQueries = $this->go_WhoisSearch($domain, $extensions, ($_REQUEST['skip_additional'] == "1"));
					}

					// display results
					$this->task_Results($whoisQueries);
				}
				else
				{
					$extensions = $base_extensions;

					// ensure extension exists
					if (empty($extensions[0]))
						$this->CORE->ERROR->stop("no_extension");

					// validate domain
					$this->CORE->DOMAINS->validateDomain($domains[0], $extensions);

					// show whois report
					$this->task_WhoisReport($domains[0], $extensions[0]);
				}
			break;

			case "MultipleWhoisSearch" :
				$this->task_MultipleWhoisSearch();
			break;


			default: $this->task_Front();
		}
	}


	/* ------------------------------------------------------------------ */
	//	Whois Search
	//	Performs whois search on $domain with $form_extensions while
	//	incorporating additional script features.
	//	RETURN: array of whois query objects
	/* ------------------------------------------------------------------ */
	
	function go_WhoisSearch($domain, $form_extensions, $skip_autosearch = false)
	{
		// +------------------------------
		//	Log Search Parameters in session
		// +------------------------------
		$this->CORE->USER->setValue("domain", $domain);
		$this->CORE->USER->setValue("extension", $form_extensions[0]);
		$this->CORE->USER->setValue("extensions", $form_extensions);

		if (!$skip_autosearch)
		{
			// append auto-search extensions, remove duplicates
			$extensions = array_unique(array_merge($form_extensions, $this->CORE->DOMAINS->getAutoSearchExtensions()));
		}
		else
		{
			$extensions = $form_extensions;
		}

		// ensure extension exists
		if (empty($extensions))
			$this->CORE->ERROR->stop("no_extension");

		// detect log type & process logs accordingly
		if (!$this->CORE->CONFIG->SCRIPT['LOGS']['all'] && !empty($form_extensions))
			$this->CORE->LOG->update($domain, $form_extensions);
		else
			$this->CORE->LOG->update($domain, $extensions);

		// extension count
		$i=0;
		foreach($extensions as $current_ext)
		{
			// only process if extension not blank
			if (!empty($current_ext))
			{
				// perform whois lookup
				$whois_queries[$i] = $this->CORE->whoisRequest($domain, $current_ext);
				$whois_queries[$i]->lookup();
				$i++;
			}
		}

		return $whois_queries;
	}


	/* ------------------------------------------------------------------ */
	//	Front task
	//	Displays front task
	/* ------------------------------------------------------------------ */
	
	function task_Front()
	{
		// display main task
		$this->CORE->DISPLAY->constructtask("main", "", "");
		$this->CORE->DISPLAY->displaytask();
	}


	/* ------------------------------------------------------------------ */
	//	Multiple Whois Search task
	//	Displays multiple TLD check task
	/* ------------------------------------------------------------------ */
	
	function task_MultipleWhoisSearch()
	{
		// display main task
		$this->CORE->DISPLAY->constructtask("multiple_tlds", "", "");
		$this->CORE->DISPLAY->displaytask();
	}


	/* ------------------------------------------------------------------ */
	//	Whois Report task
	//	Calls & Displays whois report for $domain and $ext
	/* ------------------------------------------------------------------ */
	
	function task_WhoisReport($domain, $ext)
	{
		// +------------------------------
		//	Log Search Parameters in session
		// +------------------------------
		$this->CORE->USER->setValue("domain", $domain);
		$this->CORE->USER->setValue("extension", $ext);
		$this->CORE->USER->setValue("extensions", array($ext));

		// Log query
		$this->CORE->LOG->update($domain, $ext);
		
		// +------------------------------
		//	Generate & Display task
		// +------------------------------
		// load task template
		$this->CORE->DISPLAY->constructtask("report", "", _JF_WHOIS_REPORT);

		// generate whois request
		$whois_query = $this->CORE->whoisRequest($domain, $ext);

		// perform full whois lookup
		$whois_query->lookup(true);

		// reload display
		$this->CORE->DISPLAY->reloadCore($this->CORE);

		// parse for whoisreport
		$this->CORE->DISPLAY->customParse("whoisreport", $whois_query->getWhoisReport());

		// display task
		$this->CORE->DISPLAY->displaytask();
	}


	/* ------------------------------------------------------------------ */
	//	Results task
	//	Organizes array of query objects ($whois_queries) according to
	//	results task template and displays result task
	/* ------------------------------------------------------------------ */
	
	function task_Results($whois_queries)
	{
		// load task template
		$this->CORE->DISPLAY->constructtask("results", "", _JF_SEARCH_RESULTS);

		$available_array = array();
		$unavailable_array = array();

		// cycle through queries
		foreach($whois_queries as $current_query)
		{
			// detect if query resulted in available and sort accordingly
			if ($current_query->isAvailable())
				$available_array[] = $current_query;
			else
				$unavailable_array[] = $current_query;
		}

		// parse for available/unavailable extensions
		$this->CORE->DISPLAY->parseAvailableDomains($available_array);
		$this->CORE->DISPLAY->parseUnavailableDomains($unavailable_array);

		// display task
		$this->CORE->DISPLAY->displaytask();
	}

}
